import java.awt.Color;
import java.util.Random;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;

import com.mindfusion.common.DateTime;
import com.mindfusion.drawing.Colors;
import com.mindfusion.spreadsheet.Cell;
import com.mindfusion.spreadsheet.Measure;
import com.mindfusion.spreadsheet.Workbook;
import com.mindfusion.spreadsheet.WorkbookView;
import com.mindfusion.spreadsheet.Worksheet;
import com.mindfusion.spreadsheet.charts.Chart;
import com.mindfusion.spreadsheet.charts.ChartType;
import com.mindfusion.spreadsheet.charts.PlotBy;


public class Charts
{
	public static void main(String[] args)
	{			
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				MainWindow window = new MainWindow();
				window.setTitle("JSpreadsheet Sample: Charts");
				window.setVisible(true);
			}
		});
	}
	
	public static class MainWindow extends JFrame
	{
		public MainWindow()
		{
			setDefaultCloseOperation(EXIT_ON_CLOSE);
			setSize(1280, 1024);

			Workbook workbook = new Workbook();
			Worksheet chartsSheet = workbook.getWorksheets().add("Charts");
			Worksheet dataSheet = workbook.getWorksheets().add("Data");

			WorkbookView view = new WorkbookView();
			view.setWorkbook(workbook);
			add(view);
			
			dataSheet.beginInit();
			for (int c = 1; c <= 5; c++)
				dataSheet.getCells().get(c, 0).setData(String.format("Column %1$d", c));
			for (int r = 1; r <= 5; r++)
				dataSheet.getCells().get(0, r).setData(String.format("Row %1$d", r));
			for (int c = 1; c <= 5; c++)
				for (int r = 1; r <= 5; r++)
					dataSheet.getCells().get(c, r).setData(rnd.nextInt(100));
			dataSheet.endInit();

			chartsSheet.beginInit();
			Cell cell = chartsSheet.getCells().get(0, 0);
			cell.setData("Column chart");
			Chart chart = chartsSheet.getDrawing().addChart(0, 1);
			chart.setType(ChartType.Column);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(9, 0);
			cell.setData("Bar chart");
			chart = chartsSheet.getDrawing().addChart(9, 1);
			chart.setType(ChartType.Bar);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);
			
			cell = chartsSheet.getCells().get(0, 19);
			cell.setData("Line chart with marks");
			chart = chartsSheet.getDrawing().addChart(0, 20);
			chart.setType(ChartType.LineWithMarks);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(9, 19);
			cell.setData("Stacked area chart");
			chart = chartsSheet.getDrawing().addChart(9, 20);
			chart.setType(ChartType.AreaStacked);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(0, 38);
			cell.setData("Scatter chart with smooth marks");
			chart = chartsSheet.getDrawing().addChart(0, 39);
			chart.setType(ChartType.ScatterWithSmoothLinesAndMarks);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(9, 38);
			cell.setData("Pie chart");
			chart = chartsSheet.getDrawing().addChart(9, 39);
			chart.setType(ChartType.Pie);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(0, 57);
			cell.setData("Filled radar chart");
			chart = chartsSheet.getDrawing().addChart(0, 58);
			chart.setType(ChartType.RadarFilled);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			cell = chartsSheet.getCells().get(9, 57);
			cell.setData("Bubble chart");
			chart = chartsSheet.getDrawing().addChart(9, 58);
			chart.setType(ChartType.Bubble);
			chart.setDataSource("Data!A1:F6", PlotBy.Column, true, true);

			for (Chart c: chartsSheet.getDrawing().getCharts())
			{
				c.setHorizontalOffset(Measure.point(2));
				c.setVerticalOffset(Measure.point(1));
				c.setWidth(Measure.point(400));
				c.setHeight(Measure.point(250));
				c.setLineColor(Colors.Navy);
				c.setAxisColor(new Color(45, 45, 45));
				c.setDefaultColors(new Color[]{new Color(102, 154, 204),
						new Color(90, 121, 165), 
						new Color(0, 52, 102), 
						new Color(192, 192, 192),
						new Color(206, 0, 0)});
				c.setLineSize(Measure.point(1));
			}

			chartsSheet.endInit();
		}

		private static final long serialVersionUID = 1L;

		private static final Random rnd = new Random(DateTime.now().getMillisecond());
	}
}